Returns the absolute URIs of all Parquet files that make up the current version of the Delta table. These can be passed to other tools like arrow, polars, or duckdb for reading.
Examples
if (FALSE) { # \dontrun{
dt <- delta_table("path/to/delta_table")
files <- get_files(dt)
# Use with arrow
arrow::open_dataset(files)
} # }