Inserts all columns for source rows that don't match any target rows. Requires source and target to have matching column names.
Note
This function is not yet fully supported and will error on execution.
Please use when_not_matched_insert with explicit column mappings instead.
Method arguments
The method for DeltaMergeBuilder accepts:
- predicate
Optional character. Additional predicate to filter which non-matched source rows should be inserted.
Examples
if (FALSE) { # \dontrun{
# Insert all columns for non-matched source rows (NOT YET SUPPORTED)
# Use when_not_matched_insert with explicit columns instead:
delta_merge(table, source, "target.id = source.id") |>
when_not_matched_insert(c(col1 = "source.col1", col2 = "source.col2"))
} # }